Documentation
¶
Index ¶
- func Main(out io.Writer, errOut io.Writer, args []string, exitFn func(int), name string, ...)
- func RenderAll(out io.Writer, printer *laslig.Printer) error
- func RenderCodeBlock(_ io.Writer, printer *laslig.Printer) error
- func RenderGotestout(out io.Writer, printer *laslig.Printer) error
- func RenderKV(_ io.Writer, printer *laslig.Printer) error
- func RenderList(_ io.Writer, printer *laslig.Printer) error
- func RenderLogBlock(_ io.Writer, printer *laslig.Printer) error
- func RenderMageCheckPreview(out io.Writer, printer *laslig.Printer) error
- func RenderMarkdown(_ io.Writer, printer *laslig.Printer) error
- func RenderNotice(_ io.Writer, printer *laslig.Printer) error
- func RenderPanel(_ io.Writer, printer *laslig.Printer) error
- func RenderParagraph(_ io.Writer, printer *laslig.Printer) error
- func RenderRecord(_ io.Writer, printer *laslig.Printer) error
- func RenderSection(_ io.Writer, printer *laslig.Printer) error
- func RenderSpinner(out io.Writer, printer *laslig.Printer) error
- func RenderStatusLine(_ io.Writer, printer *laslig.Printer) error
- func RenderTable(_ io.Writer, printer *laslig.Printer) error
- func Run(out io.Writer, args []string, name string, render Renderer) error
- func StylePolicyForMode(mode laslig.Mode) laslig.StylePolicy
- type Renderer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Main ¶
func Main(out io.Writer, errOut io.Writer, args []string, exitFn func(int), name string, render Renderer)
Main runs one focused example, reporting any error and delegating exit handling.
func RenderCodeBlock ¶
RenderCodeBlock demonstrates the CodeBlock primitive.
func RenderGotestout ¶
RenderGotestout demonstrates the focused gotestout example.
func RenderList ¶
RenderList demonstrates the List primitive.
func RenderLogBlock ¶
RenderLogBlock demonstrates the LogBlock primitive.
func RenderMageCheckPreview ¶
RenderMageCheckPreview demonstrates the repository-style Mage integration.
func RenderMarkdown ¶
RenderMarkdown demonstrates the Markdown primitive.
func RenderNotice ¶
RenderNotice demonstrates the Notice primitive.
func RenderPanel ¶
RenderPanel demonstrates the Panel primitive.
func RenderParagraph ¶
RenderParagraph demonstrates the Paragraph primitive.
func RenderRecord ¶
RenderRecord demonstrates the Record primitive.
func RenderSection ¶
RenderSection demonstrates how Section creates document headings and owned blocks.
func RenderSpinner ¶ added in v0.2.0
RenderSpinner demonstrates the transient Spinner helper.
func RenderStatusLine ¶
RenderStatusLine demonstrates the StatusLine primitive.
func RenderTable ¶
RenderTable demonstrates the Table primitive.
func StylePolicyForMode ¶
func StylePolicyForMode(mode laslig.Mode) laslig.StylePolicy
StylePolicyForMode converts one resolved printer mode back into a style policy for helpers that only accept a Policy.